@@ -5,7 +5,7 @@
  http://libquicktime.sourceforge.net
 
  Copyright (C) 2002 Heroine Virtual Ltd.
- Copyright (C) 2002-2007 Members of the libquicktime project.
+ Copyright (C) 2002-2011 Members of the libquicktime project.
 
  This library is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the Free
@@ -27,6 +27,7 @@
 
 #include "quicktime.h"
 #include "lqt_atoms.h"
+#include "compression.h"
 #include "lqt_codecinfo.h"
 #include "lqt_qtvr.h"
 
@@ -745,6 +746,32 @@ int lqt_get_colormodel(int index);
 
 int lqt_get_decoder_colormodel(quicktime_t * file, int track);
 
+/** \ingroup color
+ *  \brief Select a source colormodel from a provided list that is best
+ *         for conversion into a specified target colormodel.
+ *  \param source_options An array of source colormodels to select from.
+ *         Must be terminated with LQT_COLORMODEL_NODE.
+ *  \param target The target colormodel.
+ *  \return A colormodel from \p source_options or LQT_COLORMODEL_NONE,
+ *          if none of the source colormodels can be converted to the
+ *          target one.
+ */
+
+int lqt_get_best_source_colormodel(int const* source_options, int target);
+
+/** \ingroup color
+ *  \brief Select a target colormodel from a provided list that is best
+ *         for conversion from a specified source colormodel.
+ *  \param source The source colormodel.
+ *  \param target_options An array of target colormodels to select from.
+ *         Must be terminated with LQT_COLORMODEL_NODE.
+ *  \return A colormodel from \p target_options or LQT_COLORMODEL_NONE,
+ *          if the source colormodel can't be converted to any of the
+ *          target ones.
+ */
+
+int lqt_get_best_target_colormodel(int source, int const* target_options);
+
 /** \ingroup video
  *  \brief Get the best colormodel out of a list of supported colormodels
  *  \param file A quicktime handle
@@ -808,7 +835,50 @@ uint8_t ** lqt_rows_alloc(int width, int height, int colormodel, int * rowspan,
 void lqt_rows_copy(uint8_t **out_rows, uint8_t **in_rows, int width, int height, int in_rowspan, int in_rowspan_uv,
                    int out_rowspan, int out_rowspan_uv, int colormodel);
   
+/** \ingroup video
+ * \brief Copy a subrectangle video frame.
+ * \param out_rows Destination frame
+ * \param in_rows Source frame
+ * \param width Width of the frame
+ * \param height Height of the frame
+ * \param in_rowspan Rowspan for the luma plane of the input frame
+ * \param in_rowspan_uv Rowspan for the chroma planes of the input frame
+ * \param out_rowspan Rowspan for the luma plane of the output frame
+ * \param out_rowspan_uv Rowspan for the chroma planes of the output frame
+ * \param colormodel The colormodel of the frames
+ * \param src_x X offset in the source frame
+ * \param src_y Y offset in the source frame
+ * \param dst_x X offset in the destination frame
+ * \param dst_y Y offset in the destination frame
+ *
+ * Since 1.2.0
+ */
 
+void lqt_rows_copy_sub(uint8_t **out_rows, uint8_t **in_rows,
+                       int width, int height, int in_rowspan,
+                       int in_rowspan_uv, int out_rowspan,
+                       int out_rowspan_uv, int colormodel, int src_x, int src_y, int dst_x, int dst_y);
+  
+/** \ingroup video
+ * \brief Clear a video frame.
+ * \param rows Frame
+ * \param width Width of the frame
+ * \param height Height of the frame
+ * \param rowspan Rowspan for the luma plane of theframe
+ * \param rowspan_uv Rowspan for the chroma planes of the frame
+ * \param colormodel The colormodel of the frame
+ *
+ * This will set the colors to black and alpha (if available) to
+ * completely transparent.
+ *
+ * Since 1.2.0
+ * 
+ */
+
+void lqt_rows_clear(uint8_t **rows,
+                    int width, int height, int rowspan, int rowspan_uv, int colormodel);
+
+  
 /** \ingroup video
  *  \brief Free a frame allocated by \ref lqt_rows_alloc
  *  \param rows The frame to be freed
@@ -863,22 +933,36 @@ int lqt_set_video(quicktime_t *file, int tracks,
 
  
 /** \ingroup audio_encode
- *  \brief Add an audio tracks for encoding
+ *  \brief Add an audio track for encoding
  *  \param file A quicktime handle
  *  \param channels Number of channels
  *  \param sample_rate Samplerate
  *  \param bits Bits per sample (always 16)
- *  \param codec_info Codec to use (see \ref codec_registry )
+ *  \param codec_info Codec to use (see \ref codec_registry) or NULL
  *
  *  This sets adds a new audio track for encoding. Note that the bits argument
  *  should always be 16 since it's implicit to the codec in all cases.
  *  Call this function to subsequently to add as many tracks as you like.
+ *
+ *  If you passed NULL for the codec_info, you should call \ref lqt_set_audio_codec
+ *  once you know which codec to use.
  */
 
 int lqt_add_audio_track(quicktime_t *file,
                         int channels, long sample_rate, int bits,
                         lqt_codec_info_t * codec_info);
 
+/** \ingroup audio_encode
+ *  \brief Set a codec for an audio track
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param info The codec to be used for encoding
+ */
+  
+int lqt_set_audio_codec(quicktime_t *file, int track,
+                        lqt_codec_info_t * info);
+
+  
 /** \ingroup audio_encode
  *  \brief Set the audio language
  *  \param file A quicktime handle
@@ -898,12 +982,15 @@ void lqt_set_audio_language(quicktime_t * file, int track, const char * language
  *  \param frame_h Image height
  *  \param frame_duration Duration of one frame. This can later be overridden
  *  \param timescale Timescale of the track
- *  \param codec_info Codec to use (see \ref codec_registry )
+ *  \param codec_info Codec to use (see \ref codec_registry ) or NULL
  *
  *  This sets one or more video tracks for encoding. The framerate is
  *  passed as a rational number (timescale/frame_duration). E.g. for an NTSC
  *  stream, you'll choose timescale = 30000 and frame_duration = 1001.
  *  Call this function to subsequently to add as many tracks as you like.
+ *  
+ *  If you passed NULL for the codec_info, you should call \ref lqt_set_video_codec
+ *  once you know which codec to use.
  */
   
 int lqt_add_video_track(quicktime_t *file,
@@ -911,6 +998,17 @@ int lqt_add_video_track(quicktime_t *file,
                         int frame_duration, int timescale,
                         lqt_codec_info_t * codec_info);
 
+/** \ingroup video_encode
+ *  \brief Set a codec for an audio track
+ *  \param file A quicktime handle
+ *  \param track Track index (starting with 0)
+ *  \param info The codec to be used for encoding
+ */
+  
+int lqt_set_video_codec(quicktime_t *file, int track,
+                        lqt_codec_info_t * info);
+
+  
 /** \ingroup video_encode
  *  \brief Enable multipass encoding
  *  \param file A quicktime handle
@@ -998,6 +1096,27 @@ int lqt_read_video_frame(quicktime_t * file,
 int lqt_encode_video(quicktime_t *file, 
                      unsigned char **row_pointers, 
                      int track, int64_t time);
+
+/** \ingroup video_encode
+ *  \brief Encode one video frame
+ *  \param file A quicktime handle
+ *  \param row_pointers Frame (see \ref lqt_rows_alloc)
+ *  \param track Track index (starting with 0)
+ *  \param time Timestamp of the frame in timescale tics
+ *  \param duration Duration of the frame
+ *  \returns 0 if the frame was encoded, 1 else.
+ *
+ *  This is the same as \ref lqt_encode_video except that you can
+ *  pass the duration along with the timestamp. This is really only
+ *  important for the last picture, since all other durations are
+ *  calculated from the timestamp differences.
+ *
+ *  Since 1.1.2
+ */
+  
+int lqt_encode_video_d(quicktime_t *file, 
+                       unsigned char **row_pointers, 
+                       int track, int64_t time, int duration);
   
 /** \ingroup video_decode
  *  \brief Get the duration of the NEXT frame to be decoded
